#!/usr/bin/python

import re, datetime, time, os

# Date/Time Helper Functions

TIME_FORMAT = '%d %b %Y %H:%M:%S'
HTTP_FORMAT = '%a, %d %b %Y %H:%M:%S'
EPOCH_DATETIME = datetime.datetime(1970,1,1)
SECONDS_PER_DAY = 24*60*60

def string2datetime(date_string):
	'''Convert a string to a datetime object'''
	re_date = re.compile(r'\d* [A-Z][a-z]{2} \d{4} \d{2}:\d{2}:\d{2}')
	str_datetime =  re_date.findall(date_string)[0]
	datetime_ = datetime.datetime.strptime(str_datetime, TIME_FORMAT)
	return datetime_

def datetime2string(date_time):
	'''Covert a datetime object to a string which can be used for HTTP'''
	str_datetime = datetime.datetime.strftime(date_time, HTTP_FORMAT)
	str_datetime = ' '.join([str_datetime, 'GMT'])
	return str_datetime

def epochSeconds(datetime_):
	'''Convert a datetime object to Unix style epoch seconds'''
	return (datetime_ - EPOCH_DATETIME).total_seconds()

def utc2localdatetime(utc_datetime):
	'''Convert a UTC datetime to a local date/time'''
	delta_ = utc_datetime - EPOCH_DATETIME
	utc_epoch = SECONDS_PER_DAY * delta.days + delta.seconds
	time_struct = time.localtime(utc_epoch)
	dt_args = time_struc[:6] + (delta.microseconds)
	return datetime.datetime(*dt_args)

def getFileDates(file_localpath):
	'''Retrieve the cdate and mdate of a file'''
	if os.path.exists(file_localpath):
		file_cdate = datetime.datetime.utcfromtimestamp(
			os.path.getctime(file_localpath))
		file_mdate = datetime.datetime.utcfromtimestamp(
			os.path.getmtime(file_localpath))
	else:
		file_cdate = None
		file_mdate = None
	return file_cdate, file_mdate