#!/usr/bin/python

import os, sys
from configobj import ConfigObj

# Load/Save Settings

def appSettings(default_resource_path):
	'''Load settings from the Time-Drive application directory. If the 
		config file doesn't exist, return the default configuration file.'''

	# Based on the platform, locate the settings file
	if sys.platform == 'win32':
		app_data = os.getenv('APPDATA')
		app_settings = os.path.join(app_data, 'Time-Drive', 'AppSettings.config')
	else:
		app_data = os.getenv('HOME')
		app_settings = os.path.join(app_data, '.time-drive', 'AppSettings.config')

	# Check to see if the file exists
	if os.path.exists(app_settings):
		appsettings = ConfigObj(app_settings)
		return appsettings

	# If unable to find the file, look in the default resources
	else:
		try:
			settings_url = os.path.join(default_resource_path, 'AppSettings.config')
			appsettings = ConfigObj(settings_url)
			return appsettings
		except:
			return None

def collectionSettings(default_resource_path):
	'''Load settings for Time-Drive sync collections.'''

	# Based on the platform, locate the sync collections file
	if sys.platform == 'win32':
		sync_data = os.getenv('APPDATA')
		sync_settings = os.path.join(sync_data, 'Time-Drive', 'SyncCollections.config')
	else:
		sync_data = os.getenv('HOME')
		sync_settings = os.path.join(sync_data, '.time-drive', 'SyncCollections.config')

	# Check to see if the file exists
	if os.path.exists(sync_settings):
		syncsettings = ConfigObj(sync_settings)
		return syncsettings
	else:
		try:
			syncsettings_url = os.path.join(default_resource_path, 'SyncCollections.config')
			syncsettings = ConfigObj(syncsettings_url)
			return syncsettings
		except:
			return None
