#!/usr/bin/python
import sys, os, logging, posixpath, datetime

# Time-Drive imports
import sync
from sync.local import SyncFile

# Script Logic

if __name__ == '__main__':

	# Create a link to the database for a particular collection, compare the
	# contents of the collection on disk to their entries in the database.
	# If a file is missing on disk but present in the database, mark it as deleted.
	# If there is more than one version of a file in the database, locate the
	# version that matches the current MD5 signatures. Mark all other version of 
	# the file as deleted. Commit changes back to the database.
	#
	# For deleted files, look at the date which they were deleted. If more than
	# 60 days in the past, remove them from the database.

	# Load Application Settings and Sync Collections
	appsettings = sync.appSettings('resources')
	sync_collections = sync.collectionSettings('resources')

	# Configure Application Log
	ch = logging.StreamHandler()
	log = logging.getLogger()
	slog = logging.getLogger()

	logging.basicConfig(filename = os.path.join(
			appsettings['AppSettings']['Local-Settings'], 
			'Time-Drive.'+datetime.datetime.strftime(
				datetime.datetime.now(), '%Y-%m%d.%H%M')+'.log'),
		)

	log.setLevel(logging.WARNING)
	slog.addHandler(ch)
	slog.setLevel(logging.INFO)

	logging.info('Starting Database Maintainance')

	# Iterate through collections, verify database and remove unneeded entries
	for collection_name in sync_collections.keys():

		# Retrieve Settings for Collection
		sync_collection = sync_collections[collection_name]

		# Create Connection to the Database
		db_path = os.path.join(appsettings['AppSettings']['Local-Settings'],
			sync_collection['Database'])
		db_engine, db_session = sync.createDataConnection(db_path)

		# Ensure that the database tables exist
		sync.createDataTables(db_engine)

		# Retrieve information about the local dataset
		wd_ = os.path.abspath(sync_collection['Local-Path'])

		# Start Cleanup
		sync.cleanDatabase(wd_, db_session)

	logging.info('Finished Database Maintainance')