#!/usr/bin/python

import os, sys, datetime, logging, posixpath
from lxml import etree

# Time-Drive imports
import sync
from sync.local import SyncFile
from sync.backend import SyncBackend

# Script Logic

if __name__ == '__main__':

	# Downloads a manifest file from a remote server which contains information
	# about the files on the server. From the manifest, it then downloads all of
	# the files in a particular sync collection.

	# Differences are calculated by looking at the files mdate and the md5 checksum.

	# Load Application Settings and Sync Collections
	appsettings = sync.appSettings('resources')
	sync_collections = sync.collectionSettings('resources')

	# Setup backend
	server_ = appsettings['AppSettings']['Scheme'] + '://' \
		+ appsettings['AppSettings']['Host']
	server_url = posixpath.join(server_, appsettings['AppSettings']['Path'])
	sync_backend = SyncBackend(server_url, #Url of Server
		appsettings['AppSettings']['Username'], # Username
		appsettings['AppSettings']['Password'], # Password
		appsettings['AppSettings']['Backend']) # Sync Backend to Use
	sync_backend.setExcludeList(appsettings['AppSettings']['Exclude'])
	sync_backend.settingsFolder(appsettings['AppSettings']['Remote-Settings'])

	# Configure Application Log
	ch = logging.StreamHandler()
	log = logging.getLogger()
	slog = logging.getLogger()

	logging.basicConfig(filename = os.path.join(
			appsettings['AppSettings']['Local-Settings'], 
			'Time-Drive.'+datetime.datetime.strftime(
				datetime.datetime.now(), '%Y-%m%d.%H%M')+'.log'),
		)

	log.setLevel(logging.WARNING)

	slog.addHandler(ch)
	slog.setLevel(logging.INFO)

	logging.info('Sync Location: ' + server_url)

	# Start Synchronization of Collection
	for collection_name in sync_collections.keys():
		
		# Retrieve Settings for Collection
		sync_collection = sync_collections[collection_name]

		# Create Connection to the Database
		db_path = os.path.join(appsettings['AppSettings']['Local-Settings'],
			sync_collection['Database'])
		db_engine, db_session = sync.createDataConnection(db_path)

		# Ensure that the database tables Exist
		sync.createDataTables(db_engine)

		# Retrieve Url for Local Folder
		wd_ = os.path.abspath(sync_collection['Local-Path'])
		rd_ = posixpath.join(server_url, sync_collection['Remote-Path'])

		# Download Manifest from Server
		manifest_xml = sync_backend.downloadManifest(collection_name)
		if manifest_xml:
			# Parse manifest and begin sync
			rd_filelist = sync.parseManifest(manifest_xml, wd_, rd_)
			if len(rd_filelist) > 0:
				sync.downloadCollection(wd_, rd_, sync_backend, db_session, rd_filelist)
		else:
			logging.info('Unable to locate a valid manifest file for: ' + collection_name)

	logging.info(
		'Download finished for all collections: ' \
			+ str(datetime.datetime.utcnow()))
